@@ -1,7 +1,7 @@
 test_readGAlignments <- function()
 {
     fl <- system.file("extdata", "ex1.bam", package="Rsamtools")
-    which <- RangesList(seq1=IRanges(1, width=100))
+    which <- IRangesList(seq1=IRanges(1, width=100))
     param <- ScanBamParam(which=which)
     result <- readGAlignments(fl, param=param)
     checkTrue(validObject(result))
@@ -24,12 +24,12 @@ test_readGAlignments_length0 <- function()
 {
     fl <- system.file("extdata", "ex1.bam", package="Rsamtools")
 
-    which <- RangesList(seq1=IRanges(100000, width=100))
+    which <- IRangesList(seq1=IRanges(100000, width=100))
     param <- ScanBamParam(which=which)
     result <- readGAlignments(fl, param=param)
     checkTrue(validObject(result))
 
-    which <- RangesList(seq1=IRanges(c(1, 100000), width=100))
+    which <- IRangesList(seq1=IRanges(c(1, 100000), width=100))
     param <- ScanBamParam(which=which)
     result <- readGAlignments(fl, param=param)
     checkTrue(validObject(result))
